@@ -1,6 +1,5 @@
 import jieba
-import knowledge
-
+from fairies import knowledge
 stop_words = knowledge.get_stop_word()
 
 
